@@ -2,8 +2,8 @@
   include/proto/proto_http.h
   This file contains HTTP protocol definitions.
 
-  Copyright (C) 2000-2007 Willy Tarreau - w@1wt.eu
-  
+  Copyright (C) 2000-2008 Willy Tarreau - w@1wt.eu
+
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation, version 2.1
@@ -58,16 +58,15 @@ extern const char http_is_ver_token[256];
 #define HTTP_IS_VER_TOKEN(x) (http_is_ver_token[(unsigned char)(x)])
 
 int event_accept(int fd);
-void process_session(struct task *t, struct timeval *next);
 int process_cli(struct session *t);
-int process_srv(struct session *t);
+int process_srv_data(struct session *t);
+int process_srv_conn(struct session *t);
+int http_process_request(struct session *t, struct buffer *req);
+int http_process_tarpit(struct session *s, struct buffer *req);
+int http_process_request_body(struct session *s, struct buffer *req);
+int process_response(struct session *t);
 
-void client_retnclose(struct session *s, const struct chunk *msg);
-void client_return(struct session *s, const struct chunk *msg);
-void srv_close_with_err(struct session *t, int err, int finst,
-			int status, const struct chunk *msg);
-
-int produce_content(struct session *s);
+void produce_content(struct session *s, struct buffer *rep);
 int produce_content_stats(struct session *s);
 int produce_content_stats_proxy(struct session *s, struct proxy *px);
 void debug_hdr(const char *dir, struct session *t, const char *start, const char *end);
@@ -84,6 +83,12 @@ void init_proto_http();
 int http_find_header2(const char *name, int len,
 		      const char *sol, struct hdr_idx *idx,
 		      struct hdr_ctx *ctx);
+void http_sess_log(struct session *s);
+void perform_http_redirect(struct session *s, struct stream_interface *si);
+void http_return_srv_error(struct session *s, struct stream_interface *si);
+void http_capture_bad_message(struct error_snapshot *es, struct session *s,
+                              struct buffer *buf, struct http_msg *msg,
+			      struct proxy *other_end);
 
 #endif /* _PROTO_PROTO_HTTP_H */
 
