@@ -40,7 +40,7 @@ const char *proxy_cap_str(int cap);
 const char *proxy_mode_str(int mode);
 struct proxy *findproxy(const char *name, int mode, int cap);
 struct server *findserver(const struct proxy *px, const char *name);
-int proxy_cfg_ensure_no_http(struct proxy *curproxy, const char *file);
+int proxy_cfg_ensure_no_http(struct proxy *curproxy);
 
 /*
  * This function returns a string containing the type of the proxy in a format
