@@ -2,7 +2,7 @@
   include/proto/server.h
   This file defines everything related to servers.
 
-  Copyright (C) 2000-2006 Willy Tarreau - w@1wt.eu
+  Copyright (C) 2000-2009 Willy Tarreau - w@1wt.eu
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -30,10 +30,20 @@
 #include <types/server.h>
 
 #include <proto/queue.h>
+#include <proto/freq_ctr.h>
 
 int srv_downtime(struct server *s);
 int srv_getinter(struct server *s);
 
+/* increase the number of cumulated connections on the designated server */
+static void inline srv_inc_sess_ctr(struct server *s)
+{
+	s->cum_sess++;
+	update_freq_ctr(&s->sess_per_sec, 1);
+	if (s->sess_per_sec.curr_ctr > s->sps_max)
+		s->sps_max = s->sess_per_sec.curr_ctr;
+}
+
 #endif /* _PROTO_SERVER_H */
 
 /*
