@@ -70,6 +70,7 @@ struct global {
 	int spread_checks;
 	char *chroot;
 	char *pidfile;
+	char *node, *desc;		/* node name & description */
 	int logfac1, logfac2;
 	int loglev1, loglev2;
 	int minlvl1, minlvl2;
@@ -95,6 +96,7 @@ extern const int zero;
 extern const int one;
 extern const struct linger nolinger;
 extern int stopping;	/* non zero means stopping in progress */
+extern char hostname[MAX_HOSTNAME_LEN];
 
 #endif /* _TYPES_GLOBAL_H */
 
