@@ -2,7 +2,7 @@
   include/types/proto_http.h
   This file contains HTTP protocol definitions.
 
-  Copyright (C) 2000-2006 Willy Tarreau - w@1wt.eu
+  Copyright (C) 2000-2008 Willy Tarreau - w@1wt.eu
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -29,18 +29,21 @@
 
 /*
  * FIXME: break this into HTTP state and TCP socket state.
- * See client.h for the other end.
  */
 
+/* different possible states for the client side */
+#define CL_STDATA	0
+#define CL_STSHUTR	1
+#define CL_STSHUTW	2
+#define CL_STCLOSE	3
+
 /* different possible states for the server side */
 #define SV_STIDLE	0
-#define SV_STANALYZE	1  /* this server state is set by the client to study the body for server assignment */
-#define SV_STCONN	2
-#define SV_STHEADERS	3
-#define SV_STDATA	4
-#define SV_STSHUTR	5
-#define SV_STSHUTW	6
-#define SV_STCLOSE	7
+#define SV_STCONN	1
+#define SV_STDATA	2
+#define SV_STSHUTR	3
+#define SV_STSHUTW	4
+#define SV_STCLOSE	5
 
 /*
  * Transaction flags moved from session
@@ -162,6 +165,19 @@ enum {
 	DATA_ST_PX_FIN,
 };
 
+/* Redirect flags */
+enum {
+	REDIRECT_FLAG_NONE = 0,
+	REDIRECT_FLAG_DROP_QS = 1,	/* drop query string */
+};
+
+/* Redirect types (location, prefix, extended ) */
+enum {
+	REDIRECT_TYPE_NONE = 0,         /* no redirection */
+	REDIRECT_TYPE_LOCATION,         /* location redirect */
+	REDIRECT_TYPE_PREFIX,           /* prefix redirect */
+};
+
 /* Known HTTP methods */
 typedef enum {
 	HTTP_METH_NONE = 0,
@@ -215,6 +231,7 @@ struct http_msg {
 		} st;                          /* status line : field, length */
 	} sl;                                  /* start line */
 	unsigned long long hdr_content_len;    /* cache for parsed header value */
+	int err_pos;                           /* err handling: -2=block, -1=pass, 0+=detected */
 };
 
 /* This is an HTTP transaction. It contains both a request message and a
@@ -231,7 +248,6 @@ struct http_txn {
 	char *srv_cookie;		/* cookie presented by the server, in capture mode */
 	int status;			/* HTTP status from the server, negative if from proxy */
 	unsigned int flags;             /* transaction flags */
-	struct timeval exp;             /* expiration date for the transaction (generally a request) */
 };
 
 /* This structure is used by http_find_header() to return values of headers.
