@@ -1,7 +1,7 @@
 /*
  * FD polling functions for linux epoll()
  *
- * Copyright 2000-2007 Willy Tarreau <w@1wt.eu>
+ * Copyright 2000-2008 Willy Tarreau <w@1wt.eu>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,13 +17,14 @@
 #include <common/compat.h>
 #include <common/config.h>
 #include <common/standard.h>
+#include <common/ticks.h>
 #include <common/time.h>
 #include <common/tools.h>
 
 #include <types/fd.h>
 #include <types/global.h>
 
-#include <proto/fd.h>
+#include <proto/signal.h>
 #include <proto/task.h>
 
 #if defined(USE_MY_EPOLL)
@@ -221,7 +222,7 @@ REGPRM1 static void __fd_clo(int fd)
 /*
  * epoll() poller
  */
-REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
+REGPRM2 static void _do_poll(struct poller *p, int exp)
 {
 	int status;
 	int fd;
@@ -232,18 +233,21 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 		fd_flush_changes();
 
 	/* now let's wait for events */
-	if (run_queue)
+	if (run_queue || signal_queue_len)
 		wait_time = 0;
-	else if (tv_iseternity(exp))
-		wait_time = -1;
-	else if (tv_isge(&now, exp))
+	else if (!exp)
+		wait_time = MAX_DELAY_MS;
+	else if (tick_is_expired(exp, now_ms))
 		wait_time = 0;
-	else
-		wait_time = __tv_ms_elapsed(&now, exp) + 1;
+	else {
+		wait_time = TICKS_TO_MS(tick_remain(now_ms, exp)) + 1;
+		if (wait_time > MAX_DELAY_MS)
+			wait_time = MAX_DELAY_MS;
+	}
 
 	fd = MIN(maxfd, global.tune.maxpollevents);
 	status = epoll_wait(epoll_fd, epoll_events, fd, wait_time);
-	tv_now(&now);
+	tv_update_date(wait_time, status);
 
 	for (count = 0; count < status; count++) {
 		fd = epoll_events[count].data.fd;
@@ -308,7 +312,7 @@ REGPRM1 static int _do_init(struct poller *p)
 	free(epoll_events);
  fail_ee:
 	close(epoll_fd);
-	epoll_fd = 0;
+	epoll_fd = -1;
  fail_fd:
 	p->pref = 0;
 	return 0;
@@ -322,17 +326,15 @@ REGPRM1 static void _do_term(struct poller *p)
 {
 	fd_flush_changes();
 
-	if (chg_ptr)
-		free(chg_ptr);
-	if (chg_list)
-		free(chg_list);
-	if (fd_evts)
-		free(fd_evts);
-	if (epoll_events)
-		free(epoll_events);
+	free(chg_ptr);
+	free(chg_list);
+	free(fd_evts);
+	free(epoll_events);
 
-	close(epoll_fd);
-	epoll_fd = 0;
+	if (epoll_fd >= 0) {
+		close(epoll_fd);
+		epoll_fd = -1;
+	}
 
 	chg_ptr = NULL;
 	chg_list = NULL;
@@ -366,7 +368,8 @@ REGPRM1 static int _do_test(struct poller *p)
  */
 REGPRM1 static int _do_fork(struct poller *p)
 {
-	close(epoll_fd);
+	if (epoll_fd >= 0)
+		close(epoll_fd);
 	epoll_fd = epoll_create(global.maxsock + 1);
 	if (epoll_fd < 0)
 		return 0;
@@ -385,6 +388,8 @@ static void _do_register(void)
 
 	if (nbpollers >= MAX_POLLERS)
 		return;
+
+	epoll_fd = -1;
 	p = &pollers[nbpollers++];
 
 	p->name = "epoll";
