@@ -52,13 +52,14 @@
 #include <common/config.h>
 #include <common/debug.h>
 #include <common/standard.h>
+#include <common/ticks.h>
 #include <common/time.h>
 #include <common/tools.h>
 
-#include <types/fd.h>
 #include <types/global.h>
 
 #include <proto/fd.h>
+#include <proto/signal.h>
 #include <proto/task.h>
 
 #if defined(USE_MY_EPOLL)
@@ -85,7 +86,9 @@ static _syscall4 (int, epoll_wait, int, epfd, struct epoll_event *, events, int,
  *
  * Since we do not want to scan all the FD list to find speculative I/O events,
  * we store them in a list consisting in a linear array holding only the FD
- * indexes right now.
+ * indexes right now. Note that a closed FD cannot exist in the spec list,
+ * because it is closed by fd_delete() which in turn calls __fd_clo() which
+ * always removes it from the list.
  *
  * The STOP state requires the event to be present in the spec list so that
  * it can be detected and flushed upon next scan without having to scan the
@@ -155,6 +158,7 @@ struct fd_status {
 
 static int nbspec = 0;          // current size of the spec list
 static int absmaxevents = 0;    // absolute maximum amounts of polled events
+static int fd_created = 0;      // fd creation detector, reset upon poll() entry.
 
 static struct fd_status *fd_list = NULL;	// list of FDs
 static unsigned int *spec_list = NULL;	// speculative I/O list
@@ -211,6 +215,12 @@ REGPRM2 static int __fd_is_set(const int fd, int dir)
 {
 	int ret;
 
+#if DEBUG_DEV
+	if (fdtab[fd].state == FD_STCLOSE) {
+		fprintf(stderr, "sepoll.fd_isset called on closed fd #%d.\n", fd);
+		ABORT_NOW();
+	}
+#endif
 	ret = ((unsigned)fd_list[fd].e >> dir) & FD_EV_MASK_DIR;
 	return (ret == FD_EV_SPEC || ret == FD_EV_WAIT);
 }
@@ -224,10 +234,17 @@ REGPRM2 static int __fd_set(const int fd, int dir)
 	__label__ switch_state;
 	unsigned int i;
 
+#if DEBUG_DEV
+	if (fdtab[fd].state == FD_STCLOSE) {
+		fprintf(stderr, "sepoll.fd_set called on closed fd #%d.\n", fd);
+		ABORT_NOW();
+	}
+#endif
 	i = ((unsigned)fd_list[fd].e >> dir) & FD_EV_MASK_DIR;
 
 	if (i == FD_EV_IDLE) {
 		// switch to SPEC state and allocate a SPEC entry.
+		fd_created++;
 		alloc_spec_entry(fd);
 	switch_state:
 		fd_list[fd].e ^= (unsigned int)(FD_EV_IN_SL << dir);
@@ -246,6 +263,12 @@ REGPRM2 static int __fd_clr(const int fd, int dir)
 	__label__ switch_state;
 	unsigned int i;
 
+#if DEBUG_DEV
+	if (fdtab[fd].state == FD_STCLOSE) {
+		fprintf(stderr, "sepoll.fd_clr called on closed fd #%d.\n", fd);
+		ABORT_NOW();
+	}
+#endif
 	i = ((unsigned)fd_list[fd].e >> dir) & FD_EV_MASK_DIR;
 
 	if (i == FD_EV_SPEC) {
@@ -286,7 +309,7 @@ REGPRM1 static void __fd_clo(int fd)
 /*
  * speculative epoll() poller
  */
-REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
+REGPRM2 static void _do_poll(struct poller *p, int exp)
 {
 	static unsigned int last_skipped;
 	static unsigned int spec_processed;
@@ -295,8 +318,10 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 	int count;
 	int spec_idx;
 	int wait_time;
+	int looping = 0;
 
 
+ re_poll_once:
 	/* Here we have two options :
 	 * - either walk the list forwards and hope to match more events
 	 * - or walk it backwards to minimize the number of changes and
@@ -307,10 +332,16 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 	status = 0;
 	spec_idx = nbspec;
 	while (likely(spec_idx > 0)) {
+		int done;
+
 		spec_idx--;
 		fd = spec_list[spec_idx];
 		eo = fd_list[fd].e;  /* save old events */
 
+		if (looping && --fd_created < 0) {
+			/* we were just checking the newly created FDs */
+			break;
+		}
 		/*
 		 * Process the speculative events.
 		 *
@@ -321,6 +352,13 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 		 * the WAIT status.
 		 */
 
+#ifdef DEBUG_DEV
+		if (fdtab[fd].state == FD_STCLOSE) {
+			fprintf(stderr,"fd=%d, fdtab[].ev=%x, fd_list[].e=%x, .s=%d, idx=%d\n",
+				fd, fdtab[fd].ev, fd_list[fd].e, fd_list[fd].s1, spec_idx);
+		}
+#endif
+		done = 0;
 		fdtab[fd].ev &= FD_POLL_STICKY;
 		if ((eo & FD_EV_MASK_R) == FD_EV_SPEC_R) {
 			/* The owner is interested in reading from this FD */
@@ -330,7 +368,7 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 				if (!fdtab[fd].cb[DIR_RD].f(fd))
 					fd_list[fd].e ^= (FD_EV_WAIT_R ^ FD_EV_SPEC_R);
 				else
-					status++;
+					done = 1;
 			}
 		}
 		else if ((eo & FD_EV_MASK_R) == FD_EV_STOP_R) {
@@ -346,7 +384,7 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 				if (!fdtab[fd].cb[DIR_WR].f(fd))
 					fd_list[fd].e ^= (FD_EV_WAIT_W ^ FD_EV_SPEC_W);
 				else
-					status++;
+					done = 1;
 			}
 		}
 		else if ((eo & FD_EV_MASK_W) == FD_EV_STOP_W) {
@@ -354,6 +392,11 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 			fd_list[fd].e &= ~FD_EV_MASK_W;
 		}
 
+		status += done;
+		/* one callback might already have closed the fd by itself */
+		if (fdtab[fd].state == FD_STCLOSE)
+			continue;
+
 		/* Now, we will adjust the event in the poll list. Indeed, it
 		 * is possible that an event which was previously in the poll
 		 * list now goes out, and the opposite is possible too. We can
@@ -412,18 +455,24 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 	 */
 
 	spec_processed += status;
+
+	if (looping) {
+		last_skipped++;
+		return;
+	}
+
 	if (status >= MIN_RETURN_EVENTS && spec_processed < absmaxevents) {
 		/* We have processed at least MIN_RETURN_EVENTS, it's worth
 		 * returning now without checking epoll_wait().
 		 */
 		if (++last_skipped <= 1) {
-			tv_now(&now);
+			tv_update_date(0, 1);
 			return;
 		}
 	}
 	last_skipped = 0;
 
-	if (nbspec || status || run_queue) {
+	if (nbspec || status || run_queue || signal_queue_len) {
 		/* Maybe we have processed some events that we must report, or
 		 * maybe we still have events in the spec list, or there are
 		 * some tasks left pending in the run_queue, so we must not
@@ -433,12 +482,15 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 		wait_time = 0;
 	}
 	else {
-		if (tv_iseternity(exp))
-			wait_time = -1;
-		else if (tv_isge(&now, exp))
+		if (!exp)
+			wait_time = MAX_DELAY_MS;
+		else if (tick_is_expired(exp, now_ms))
 			wait_time = 0;
-		else
-			wait_time = __tv_ms_elapsed(&now, exp) + 1;
+		else {
+			wait_time = TICKS_TO_MS(tick_remain(now_ms, exp)) + 1;
+			if (wait_time > MAX_DELAY_MS)
+				wait_time = MAX_DELAY_MS;
+		}
 	}
 
 	/* now let's wait for real events. We normally use maxpollevents as a
@@ -448,10 +500,11 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 	fd = MIN(absmaxevents, spec_processed);
 	fd = MAX(global.tune.maxpollevents, fd);
 	fd = MIN(maxfd, fd);
+	/* we want to detect if an accept() will create new speculative FDs here */
+	fd_created = 0;
 	spec_processed = 0;
 	status = epoll_wait(epoll_fd, epoll_events, fd, wait_time);
-
-	tv_now(&now);
+	tv_update_date(wait_time, status);
 
 	for (count = 0; count < status; count++) {
 		int e = epoll_events[count].events;
@@ -486,6 +539,18 @@ REGPRM2 static void _do_poll(struct poller *p, struct timeval *exp)
 				fdtab[fd].cb[DIR_WR].f(fd);
 		}
 	}
+
+	if (fd_created) {
+		/* we have created some fds, certainly in return of an accept(),
+		 * and they're marked as speculative. If we can manage to perform
+		 * a read(), we're almost sure to collect all the request at once
+		 * and avoid several expensive wakeups. So let's try now. Anyway,
+		 * if we fail, the tasks are still woken up, and the FD gets marked
+		 * for poll mode.
+		 */
+		looping = 1;
+		goto re_poll_once;
+	}
 }
 
 /*
@@ -526,7 +591,7 @@ REGPRM1 static int _do_init(struct poller *p)
 	free(epoll_events);
  fail_ee:
 	close(epoll_fd);
-	epoll_fd = 0;
+	epoll_fd = -1;
  fail_fd:
 	p->pref = 0;
 	return 0;
@@ -538,15 +603,14 @@ REGPRM1 static int _do_init(struct poller *p)
  */
 REGPRM1 static void _do_term(struct poller *p)
 {
-	if (fd_list)
-		free(fd_list);
-	if (spec_list)
-		free(spec_list);
-	if (epoll_events)
-		free(epoll_events);
+	free(fd_list);
+	free(spec_list);
+	free(epoll_events);
 
-	close(epoll_fd);
-	epoll_fd = 0;
+	if (epoll_fd >= 0) {
+		close(epoll_fd);
+		epoll_fd = -1;
+	}
 
 	fd_list = NULL;
 	spec_list = NULL;
@@ -579,7 +643,8 @@ REGPRM1 static int _do_test(struct poller *p)
  */
 REGPRM1 static int _do_fork(struct poller *p)
 {
-	close(epoll_fd);
+	if (epoll_fd >= 0)
+		close(epoll_fd);
 	epoll_fd = epoll_create(global.maxsock + 1);
 	if (epoll_fd < 0)
 		return 0;
@@ -598,6 +663,8 @@ static void _do_register(void)
 
 	if (nbpollers >= MAX_POLLERS)
 		return;
+
+	epoll_fd = -1;
 	p = &pollers[nbpollers++];
 
 	p->name = "sepoll";
