@@ -152,12 +152,7 @@ const int zero = 0;
 const int one = 1;
 const struct linger nolinger = { .l_onoff = 1, .l_linger = 0 };
 
-/*
- * Syslog facilities and levels. Conforming to RFC3164.
- */
-
-#define MAX_HOSTNAME_LEN	32
-static char hostname[MAX_HOSTNAME_LEN] = "";
+char hostname[MAX_HOSTNAME_LEN] = "";
 
 
 /*********************************************************************/
@@ -188,7 +183,13 @@ void display_build_opts()
 #ifdef BUILD_OPTIONS
 	       "\n  OPTIONS = " BUILD_OPTIONS
 #endif
-	       "\n\n");
+	       "\n\nDefault settings :"
+	       "\n  maxconn = %d, maxpollevents = %d"
+	       "\n\n",
+	       DEFAULT_MAXCONN, MAX_POLL_EVENTS);
+
+	list_pollers(stdout);
+	putchar('\n');
 }
 
 /*
@@ -675,6 +676,9 @@ void init(int argc, char **argv)
 		printf("Using %s() as the polling mechanism.\n", cur_poller.name);
 	}
 
+	if (!global.node)
+		global.node = strdup(hostname);
+
 }
 
 void deinit(void)
@@ -841,6 +845,8 @@ void deinit(void)
 
 		free(uap->uri_prefix);
 		free(uap->auth_realm);
+		free(uap->node);
+		free(uap->desc);
 
 		while (uap->users) {
 			user = uap->users;
@@ -855,6 +861,8 @@ void deinit(void)
 
 	free(global.chroot);  global.chroot = NULL;
 	free(global.pidfile); global.pidfile = NULL;
+	free(global.node);    global.node = NULL;
+	free(global.desc);    global.desc = NULL;
 	free(fdtab);          fdtab   = NULL;
 	free(oldpids);        oldpids = NULL;
 
@@ -938,7 +946,7 @@ int main(int argc, char **argv)
 	/* on very high loads, a sigpipe sometimes happen just between the
 	 * getsockopt() which tells "it's OK to write", and the following write :-(
 	 */
-#if !defined(MSG_NOSIGNAL) || defined(CONFIG_HAP_LINUX_SPLICE)
+#if !MSG_NOSIGNAL || defined(CONFIG_HAP_LINUX_SPLICE)
 	signal(SIGPIPE, SIG_IGN);
 #endif
 
