@@ -14,9 +14,6 @@
 #include <common/memory.h>
 #include <common/time.h>
 
-#include <types/proxy.h>
-#include <types/session.h>
-
 #include <proto/queue.h>
 #include <proto/server.h>
 #include <proto/task.h>
@@ -80,7 +77,7 @@ void process_srv_queue(struct server *s)
 		struct session *sess = pendconn_get_next_sess(s, p);
 		if (sess == NULL)
 			break;
-		task_wakeup(sess->task);
+		task_wakeup(sess->task, TASK_WOKEN_RES);
 	}
 }
 
