@@ -301,8 +301,9 @@ int stream_sock_read(int fd) {
 		/*
 		 * 2. read the largest possible block
 		 */
-#ifndef MSG_NOSIGNAL
-		{
+		if (MSG_NOSIGNAL) {
+			ret = recv(fd, b->r, max, MSG_NOSIGNAL);
+		} else {
 			int skerr;
 			socklen_t lskerr = sizeof(skerr);
 
@@ -312,9 +313,7 @@ int stream_sock_read(int fd) {
 			else
 				ret = recv(fd, b->r, max, 0);
 		}
-#else
-		ret = recv(fd, b->r, max, MSG_NOSIGNAL);
-#endif
+
 		if (ret > 0) {
 			b->r += ret;
 			b->l += ret;
@@ -574,8 +573,9 @@ static int stream_sock_write_loop(struct stream_interface *si, struct buffer *b)
 		if (max > b->send_max)
 			max = b->send_max;
 
-#ifndef MSG_NOSIGNAL
-		{
+		if (MSG_NOSIGNAL) {
+			ret = send(si->fd, b->w, max, MSG_DONTWAIT | MSG_NOSIGNAL);
+		} else {
 			int skerr;
 			socklen_t lskerr = sizeof(skerr);
 
@@ -585,9 +585,6 @@ static int stream_sock_write_loop(struct stream_interface *si, struct buffer *b)
 			else
 				ret = send(si->fd, b->w, max, MSG_DONTWAIT);
 		}
-#else
-		ret = send(si->fd, b->w, max, MSG_DONTWAIT | MSG_NOSIGNAL);
-#endif
 
 		if (ret > 0) {
 			if (fdtab[si->fd].state == FD_STCONN)
@@ -732,12 +729,14 @@ int stream_sock_write(int fd)
 			b->wex = tick_add_ifset(now_ms, b->wto);
 
 	out_wakeup:
-		if (tick_isset(si->ib->rex)) {
+		if (tick_isset(si->ib->rex) && !(si->flags & SI_FL_INDEP_STR)) {
 			/* Note: to prevent the client from expiring read timeouts
-			 * during writes, we refresh it. A better solution would be
-			 * to merge read+write timeouts into a unique one, although
-			 * that needs some study particularly on full-duplex TCP
-			 * connections.
+			 * during writes, we refresh it. We only do this if the
+			 * interface is not configured for "independant streams",
+			 * because for some applications it's better not to do this,
+			 * for instance when continuously exchanging small amounts
+			 * of data which can full the socket buffers long before a
+			 * write timeout is detected.
 			 */
 			si->ib->rex = tick_add_ifset(now_ms, si->ib->rto);
 		}
@@ -880,12 +879,12 @@ void stream_sock_data_finish(struct stream_interface *si)
 		else {
 			/* (re)start reading and update timeout. Note: we don't recompute the timeout
 			 * everytime we get here, otherwise it would risk never to expire. We only
-			 * update it if is was not yet set, or if we already got some read status.
+			 * update it if is was not yet set. The stream socket handler will already
+			 * have updated it if there has been a completed I/O.
 			 */
 			si->flags &= ~SI_FL_WAIT_ROOM;
 			EV_FD_COND_S(fd, DIR_RD);
-			if (!(ib->flags & BF_READ_NOEXP) &&
-			    (!tick_isset(ib->rex) || ib->flags & BF_READ_ACTIVITY))
+			if (!(ib->flags & BF_READ_NOEXP) && !tick_isset(ib->rex))
 				ib->rex = tick_add_ifset(now_ms, ib->rto);
 		}
 	}
@@ -905,17 +904,19 @@ void stream_sock_data_finish(struct stream_interface *si)
 		else {
 			/* (re)start writing and update timeout. Note: we don't recompute the timeout
 			 * everytime we get here, otherwise it would risk never to expire. We only
-			 * update it if is was not yet set, or if we already got some write status.
+			 * update it if is was not yet set. The stream socket handler will already
+			 * have updated it if there has been a completed I/O.
 			 */
 			si->flags &= ~SI_FL_WAIT_DATA;
 			EV_FD_COND_S(fd, DIR_WR);
-			if (!tick_isset(ob->wex) || ob->flags & BF_WRITE_ACTIVITY) {
+			if (!tick_isset(ob->wex)) {
 				ob->wex = tick_add_ifset(now_ms, ob->wto);
-				if (tick_isset(ib->rex)) {
+				if (tick_isset(ib->rex) && !(si->flags & SI_FL_INDEP_STR)) {
 					/* Note: depending on the protocol, we don't know if we're waiting
 					 * for incoming data or not. So in order to prevent the socket from
 					 * expiring read timeouts during writes, we refresh the read timeout,
-					 * except if it was already infinite.
+					 * except if it was already infinite or if we have explicitly setup
+					 * independant streams.
 					 */
 					ib->rex = tick_add_ifset(now_ms, ib->rto);
 				}
@@ -1039,12 +1040,14 @@ void stream_sock_chk_snd(struct stream_interface *si)
 		    (ob->flags & (BF_SHUTW|BF_WRITE_PARTIAL)) == BF_WRITE_PARTIAL)
 			ob->wex = tick_add_ifset(now_ms, ob->wto);
 
-		if (tick_isset(si->ib->rex)) {
+		if (tick_isset(si->ib->rex) && !(si->flags & SI_FL_INDEP_STR)) {
 			/* Note: to prevent the client from expiring read timeouts
-			 * during writes, we refresh it. A better solution would be
-			 * to merge read+write timeouts into a unique one, although
-			 * that needs some study particularly on full-duplex TCP
-			 * connections.
+			 * during writes, we refresh it. We only do this if the
+			 * interface is not configured for "independant streams",
+			 * because for some applications it's better not to do this,
+			 * for instance when continuously exchanging small amounts
+			 * of data which can full the socket buffers long before a
+			 * write timeout is detected.
 			 */
 			si->ib->rex = tick_add_ifset(now_ms, si->ib->rto);
 		}
